@@ -1,6 +1,6 @@
 package Workflow::Persister;
 
-# $Id: Persister.pm 454 2009-01-12 10:04:02Z jonasbn $
+# $Id: Persister.pm 598 2013-07-03 09:52:32Z jonasbn $
 
 use warnings;
 use strict;
@@ -10,7 +10,7 @@ use Workflow::Exception qw( persist_error );
 
 use constant DEFAULT_ID_LENGTH => 8;
 
-$Workflow::Persister::VERSION = '1.09';
+$Workflow::Persister::VERSION = '1.10';
 
 my @FIELDS = qw( name class
     use_random use_uuid
@@ -98,7 +98,7 @@ sub fetch_extra_workflow_data {
     $log->debug(
         "An empty implementation is not an error as you may ",
         "not need this extra functionality. If you do you ",
-        "should use a perister for this purpose (e.g., ",
+        "should use a persister for this purpose (e.g., ",
         "Workflow::Persister::DBI::ExtraData) or ",
         "create your own and just implement this method."
     );
@@ -117,6 +117,21 @@ sub fetch_history {
         "'fetch_history()'";
 }
 
+sub get_create_user {
+    my ( $self, $wf ) = @_;
+    return 'n/a';
+}
+
+sub get_create_description {
+    my ( $self, $wf ) = @_;
+    return 'Create new workflow';
+}
+
+sub get_create_action {
+    my ( $self, $wf ) = @_;
+    return 'Create workflow';
+}
+
 # Only required for DBI persisters.
 sub commit_transaction {
     return;
@@ -209,6 +224,30 @@ Persister. Since this is a SUPER class.
 
 The derived class method should return a list of L<Workflow::History> objects.
 
+
+=head3 get_create_user( $workflow )
+
+When creating an initial L<Workflow::History> record to insert into the database,
+the return value of this method is used for the value of the "user" field.
+
+Override this method to change the value from the default, "n/a".
+
+=head3 get_create_description( $workflow )
+
+When creating an initial L<Workflow::History> record to insert into the database,
+the return value of this method is used for the value of the "description" field.
+
+Override this method to change the value from the default, "Create new workflow".
+
+
+=head3 get_create_action( $workflow )
+
+When creating an initial L<Workflow::History> record to insert into the database,
+the return value of this method is used for the value of the "action" field.
+
+Override this method to change the value from the default, "Create workflow".
+
+
 =head3 assign_generators( \%params ) 
 
 Assigns proper generators based on intialization, see L</init>
