@@ -1,6 +1,6 @@
 package Workflow::State;
 
-# $Id: State.pm 566 2012-11-08 21:22:56Z jonasbn $
+# $Id: State.pm 588 2012-11-11 14:01:45Z jonasbn $
 
 use warnings;
 use strict;
@@ -11,7 +11,7 @@ use Workflow::Exception qw( workflow_error );
 use Workflow::Factory qw( FACTORY );
 use English qw( -no_match_vars );
 
-$Workflow::State::VERSION = '1.15';
+$Workflow::State::VERSION = '1.16';
 
 my @FIELDS   = qw( state description type );
 my @INTERNAL = qw( _test_condition_count _factory );
@@ -50,9 +50,8 @@ sub get_available_action_names {
     foreach my $action_name (@all_actions) {
 
         #From Ivan Paponov
-        my $action_group
-            = $self->_factory()->{_action_config}{ $self->type() }{$action_name}
-            {'group'};
+        my $action_group = $self->_factory()
+            ->{_action_config}{ $self->type() }{$action_name}{'group'};
 
         if ( defined $group && length $group ) {
             if ( $action_group ne $group ) {
@@ -164,8 +163,8 @@ sub evaluate_action {
                 # name. As the result has not been cached, we have
                 # to get the real condition with the original
                 # condition name and evaluate that
-                $condition = $self->_factory()->get_condition( $orig_condition,
-                    $self->type() );
+                $condition = $self->_factory()
+                    ->get_condition( $orig_condition, $self->type() );
             }
             $log->is_debug
                 && $log->debug( q{Evaluating condition '},
@@ -272,7 +271,7 @@ sub may_stop {
 
 sub init {
     my ( $self, $config, $factory ) = @_;
-    
+
     # Fallback for old style
     $factory ||= FACTORY;
     $log ||= get_logger();
@@ -284,8 +283,8 @@ sub init {
         && $log->debug("Constructing '$class' object for state $name");
 
     $self->state($name);
-    $self->_factory( $factory );
-    
+    $self->_factory($factory);
+
     # Note this is the workflow type.
     $self->type( $config->{type} );
     $self->description( $config->{description} );
@@ -395,8 +394,8 @@ sub _create_condition_objects {
                     && $log->info(
                     "Fetching condition '$condition_info->{name}'");
                 push @condition_objects,
-                    $self->_factory()->get_condition( $condition_info->{name},
-                    $self->type() );
+                    $self->_factory()
+                    ->get_condition( $condition_info->{name}, $self->type() );
             }
         }
     }
